==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropAlias.h <==
// public final class soot.jimple.spark.solver.PropAlias

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 16081ab54f64caed soot_jimple_spark_solver_PropAlias
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropAlias_H_
#define _JC_soot_jimple_spark_solver_PropAlias_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;
struct _jc_soot_util_LargeNumberedMap$object;
struct _jc_soot_util_MultiMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropAlias$sub_refs	_jc_soot_jimple_spark_solver_PropAlias$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs	_jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$refs	_jc_soot_jimple_spark_solver_PropAlias$refs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$nonrefs	_jc_soot_jimple_spark_solver_PropAlias$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$object	_jc_soot_jimple_spark_solver_PropAlias$object;

typedef const struct _jc_soot_jimple_spark_solver_PropAlias$vmethods	_jc_soot_jimple_spark_solver_PropAlias$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropAlias$vtable	_jc_soot_jimple_spark_solver_PropAlias$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropAlias$vtype	_jc_soot_jimple_spark_solver_PropAlias$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropAlias$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropAlias$method$addToWorklist$57ef72b71645f5b6(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_solver_PropAlias$method$getP2Set$d48ba7ee83c97938(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropAlias$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropAlias$method$handleVarNode$38f043a08670ae06(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_solver_PropAlias$method$makeP2Set$46e23aeb8832324b(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
extern void _jc_soot_jimple_spark_solver_PropAlias$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$addToWorklist$57ef72b71645f5b6;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$getP2Set$d48ba7ee83c97938;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$handleVarNode$38f043a08670ae06;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$makeP2Set$46e23aeb8832324b;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropAlias$vmethods {
	jboolean	(*addToWorklist$57ef72b71645f5b6)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*getP2Set$d48ba7ee83c97938)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	jboolean	(*handleVarNode$38f043a08670ae06)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*makeP2Set$46e23aeb8832324b)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropAlias$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropAlias$vmethods	soot_jimple_spark_solver_PropAlias;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropAlias$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropAlias$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropAlias$sub_refs {
	struct _jc_object	*varNodeWorkList;
	struct _jc_object	*aliasWorkList;
	struct _jc_object	*fieldRefWorkList;
	struct _jc_object	*outFieldRefWorkList;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_object	*fieldToBase;
	struct _jc_object	*aliasEdges;
	struct _jc_soot_util_LargeNumberedMap$object	*loadSets;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropAlias$refs {
    _jc_soot_jimple_spark_solver_PropAlias$sub_refs	soot_jimple_spark_solver_PropAlias;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropAlias$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs	soot_jimple_spark_solver_PropAlias;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropAlias$object {
	_jc_soot_jimple_spark_solver_PropAlias$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropAlias$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropAlias$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropAlias$vtype _jc_soot_jimple_spark_solver_PropAlias$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropAlias, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropAlias$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropAlias_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropAlias.h <==
// public final class soot.jimple.spark.solver.PropAlias

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 16081ab54f64caed soot_jimple_spark_solver_PropAlias
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropAlias_H_
#define _JC_soot_jimple_spark_solver_PropAlias_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;
struct _jc_soot_util_LargeNumberedMap$object;
struct _jc_soot_util_MultiMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropAlias$sub_refs	_jc_soot_jimple_spark_solver_PropAlias$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs	_jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$refs	_jc_soot_jimple_spark_solver_PropAlias$refs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$nonrefs	_jc_soot_jimple_spark_solver_PropAlias$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropAlias$object	_jc_soot_jimple_spark_solver_PropAlias$object;

typedef const struct _jc_soot_jimple_spark_solver_PropAlias$vmethods	_jc_soot_jimple_spark_solver_PropAlias$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropAlias$vtable	_jc_soot_jimple_spark_solver_PropAlias$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropAlias$vtype	_jc_soot_jimple_spark_solver_PropAlias$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropAlias$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropAlias$method$addToWorklist$57ef72b71645f5b6(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_solver_PropAlias$method$getP2Set$d48ba7ee83c97938(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropAlias$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropAlias$method$handleVarNode$38f043a08670ae06(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_solver_PropAlias$method$makeP2Set$46e23aeb8832324b(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_PropAlias$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$addToWorklist$57ef72b71645f5b6;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$getP2Set$d48ba7ee83c97938;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$handleVarNode$38f043a08670ae06;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$makeP2Set$46e23aeb8832324b;
extern _jc_method _jc_soot_jimple_spark_solver_PropAlias$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropAlias$vmethods {
	jboolean	(*addToWorklist$57ef72b71645f5b6)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*getP2Set$d48ba7ee83c97938)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	jboolean	(*handleVarNode$38f043a08670ae06)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*makeP2Set$46e23aeb8832324b)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropAlias$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropAlias$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropAlias$vmethods	soot_jimple_spark_solver_PropAlias;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropAlias$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropAlias$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropAlias$sub_refs {
	struct _jc_object	*varNodeWorkList;
	struct _jc_object	*aliasWorkList;
	struct _jc_object	*fieldRefWorkList;
	struct _jc_object	*outFieldRefWorkList;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_object	*fieldToBase;
	struct _jc_object	*aliasEdges;
	struct _jc_soot_util_LargeNumberedMap$object	*loadSets;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropAlias$refs {
    _jc_soot_jimple_spark_solver_PropAlias$sub_refs	soot_jimple_spark_solver_PropAlias;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropAlias$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropAlias$sub_nonrefs	soot_jimple_spark_solver_PropAlias;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropAlias$object {
	_jc_soot_jimple_spark_solver_PropAlias$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropAlias$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropAlias$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropAlias$vtype _jc_soot_jimple_spark_solver_PropAlias$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropAlias, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropAlias$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropAlias_H_ */
